<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# Home (Zensical)

Welcome to the Zensical sandbox.

## Links

- [Features](features.md) — valid link
- [Private Notes](_private/notes.md) — TRAP: file in _private dir → UNREACHABLE_LINK (IGNORED route)
- [Missing Page](missing.md) — TRAP: file does not exist → FILE_NOT_FOUND
